@@ -18,24 +18,27 @@
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
-     $Id$
-
 --------------------------------------------------------------------------- */
 #include <stdio.h>
 #include <discid/discid.h>
 
+#ifndef DISCID_HAVE_SPARSE_READ
+#define discid_read_sparse(disc, dev, i) discid_read(disc, dev)
+#endif
+
 
 int main(int argc, char *argv[]) {
 	DiscId *disc = discid_new();
 	int i;
-        char *device = NULL;
+	char *device = NULL;
 
-        /* If we have an argument, use it as the device name */
-        if (argc > 1)
-            device = argv[1];
+	/* If we have an argument, use it as the device name */
+	if (argc > 1) {
+		device = argv[1];
+	}
 
-	/* read the disc in the default disc drive */
-	if ( discid_read(disc, device) == 0 ) {
+	/* read the disc in the specified (or default) disc drive */
+	if (discid_read_sparse(disc, device, 0) == 0) {
 		fprintf(stderr, "Error: %s\n", discid_get_error_msg(disc));
 		return 1;
 	}
